==> tecfy_basic_package-0.0.1.tar.gz: lib/views/components/text_form_feild.dart <==
part of tecfy_basic_package;

class AppTextFormField extends StatelessWidget {
  final TextInputAction textInputAction;
  final TextEditingController controller;
  final String Function(String) validator;
  final void Function() onEditingComplete;
  final TextInputType keyboardType;
  final String labelText;
  final bool obscureText;
  final bool autoFocus;
  final int maxLines;
  final  FocusNode focusNode;
  AppTextFormField(
      {this.textInputAction,
      this.controller,
      this.validator,
      this.keyboardType,
      this.labelText,
      this.onEditingComplete,
      this.focusNode,
      this.obscureText = false,
      this.autoFocus = false,
      this.maxLines = 1});

  @override
  Widget build(BuildContext context) {
    if (maxLines > 1)
      return getMultiRowText(context);
    else
      return Theme.of(context).platform == TargetPlatform.iOS
          ?
          //labelText == "Email Address"?
          Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                  Text(labelText, style: TextStyle(fontSize: 12.0)),
                  CupertinoTextField(
                      controller: controller,
                      textInputAction: textInputAction,
                      keyboardType: keyboardType,
                      //validator: validator,
                      onEditingComplete:onEditingComplete,
                      obscureText: obscureText,
                      maxLines: maxLines,
                      placeholder: labelText,
                      focusNode:focusNode,
                      autofocus: autoFocus,
                      decoration: BoxDecoration()),
                  Container(height: 1.0, color: Colors.black),
                  SizedBox(height: 15.0)
                ])
          : TextFormField(
              enableInteractiveSelection: true,
              textInputAction: textInputAction,
              keyboardType: keyboardType,
              controller: controller,
              onEditingComplete:onEditingComplete,
              focusNode: focusNode,
              validator: validator,
              obscureText: obscureText,
              maxLines: maxLines,
              autofocus: autoFocus,
              decoration: InputDecoration(labelText: labelText)
            );
  }

  getMultiRowText(context) {
    return Theme.of(context).platform == TargetPlatform.iOS
        ? Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
                Text(labelText, style: TextStyle(fontSize: 12.0)),
                SizedBox(height: 5.9,),
                Container(
                    height: 25.0 * maxLines,
                    decoration: ShapeDecoration(
                        shape: RoundedRectangleBorder(
                            borderRadius:
                                BorderRadius.all(Radius.circular(2.0)),
                            side: BorderSide(color: Colors.black38))),
                    child: Scrollbar(
                        child: SingleChildScrollView(
                            child: CupertinoTextField(
                                controller: controller,
                                onEditingComplete:onEditingComplete,
                                focusNode:focusNode,
                                textInputAction: textInputAction,
                                keyboardType: TextInputType.multiline,
                                obscureText: obscureText,
                                maxLines: 5,
                                placeholder: labelText,
                                decoration: BoxDecoration()))))
              ])
        : TextFormField(
            enableInteractiveSelection: true,
            textInputAction: textInputAction,
            keyboardType: TextInputType.multiline,
            controller: controller,
            onEditingComplete:onEditingComplete,
            validator: validator,
            obscureText: obscureText,
            focusNode:focusNode,
            maxLines: maxLines,
            decoration: InputDecoration(labelText: labelText),
          );
  }
}

==> tecfy_basic_package-0.1.2.tar.gz: lib/views/components/text_form_feild.dart <==
part of tecfy_basic_package;

class AppTextFormField extends StatelessWidget {
  final TextInputAction textInputAction;
  final TextEditingController controller;
  final String Function(String) validator;
  final void Function() onEditingComplete;
  final TextInputType keyboardType;
  final String labelText;
  final Widget icon;
  final bool obscureText;
  final bool autoFocus;
  final int maxLines;
  final  FocusNode focusNode;
  final bool isDarkBackgound;
  AppTextFormField(
      {this.textInputAction,
      this.controller,
      this.isDarkBackgound =false,
      this.icon,
      this.validator,
      this.keyboardType,
      this.labelText,
      this.onEditingComplete,
      this.focusNode,
      this.obscureText = false,
      this.autoFocus = false,
      this.maxLines = 1});

  @override
  Widget build(BuildContext context) {
    Widget result;
    if (maxLines > 1)
      result = getMultiRowText(context);
    else
      result = icon == null ? getSingleRowText(context) : Stack(children: <Widget>[
        getSingleRowText(context),
        Container(
          height: 60,
          padding: EdgeInsets.only(right:10,left:10),
          child: Align(child:icon, 
            alignment: ConfigService.isRTL ? Alignment.centerLeft : Alignment.centerRight )
        )
      ]);

      
      return isDarkBackgound ?
       Theme(child: result,data: ThemeData.dark()) 
       : result;
  }

  Widget getSingleRowText(context){

    return  Theme.of(context).platform == TargetPlatform.iOS
          ?
          //labelText == "Email Address"?
          Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                  Text(labelText, style: TextStyle(fontSize: 12.0)),
                  CupertinoTextField(
                      controller: controller,
                      textInputAction: textInputAction,
                      keyboardType: keyboardType,
                      //validator: validator,
                      onEditingComplete:onEditingComplete,
                      obscureText: obscureText,
                      maxLines: maxLines,
                      placeholder: labelText,
                      focusNode:focusNode,
                      autofocus: autoFocus,
                      decoration: BoxDecoration()),
                  Container(height: 1.0, color: isDarkBackgound ? Colors.white : Colors.black),
                  SizedBox(height: 15.0)
                ])
          : TextFormField(
              enableInteractiveSelection: !obscureText,
              textInputAction: textInputAction,
              keyboardType: keyboardType,
              controller: controller,
              onEditingComplete:onEditingComplete,
              focusNode: focusNode,
              validator: validator,
              obscureText: obscureText,
              maxLines: maxLines,
              autofocus: autoFocus,
              enableSuggestions: true,
              decoration: InputDecoration(
                  labelText: labelText, 
                  border: UnderlineInputBorder()
                  )
            );

  }

  getMultiRowText(context) {
    return Theme.of(context).platform == TargetPlatform.iOS
        ? Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
                Text(labelText, style: TextStyle(fontSize: 12.0)),
                SizedBox(height: 5.9,),
                Container(
                    height: 25.0 * maxLines,
                    decoration: ShapeDecoration(
                        shape: RoundedRectangleBorder(
                            borderRadius:
                                BorderRadius.all(Radius.circular(2.0)),
                            side: BorderSide(color: Colors.black38))),
                    child: Scrollbar(
                        child: SingleChildScrollView(
                            child: CupertinoTextField(
                                controller: controller,
                                onEditingComplete:onEditingComplete,
                                focusNode:focusNode,
                                textInputAction: textInputAction,
                                keyboardType: TextInputType.multiline,
                                obscureText: obscureText,
                                maxLines: 5,
                                placeholder: labelText,
                                decoration: BoxDecoration()))))
              ])
        : TextFormField(
            enableInteractiveSelection: true,
            textInputAction: textInputAction,
            keyboardType: TextInputType.multiline,
            controller: controller,
            onEditingComplete:onEditingComplete,
            validator: validator,
            obscureText: obscureText,
            focusNode:focusNode,
            maxLines: maxLines,
            decoration: InputDecoration(labelText: labelText),
          );
  }
}
